# ComponentShortfall

Generate component shortfall reports

## Installation

### InvenTree Plugin Manager

... todo ...

### Command Line 

To install manually via the command line, run the following command:

```bash
pip install inventree-component-shortfall
```

## Configuration

... todo ...

## Usage

... todo ...
